/*
 * Copyright 2006 Alexandre Julliard
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */

#include <stdarg.h>
#include "windef.h"
#include "winbase.h"
#include "vdmdbg.h"

#include "wine/debug.h"

WINE_DEFAULT_DEBUG_CHANNEL(vdmdbg);

/***********************************************************************
 *      VDMEnumTaskWOW  (VDMDBG.@)
 */
INT WINAPI VDMEnumTaskWOW(DWORD dwProcessId, TASKENUMPROC fp, LPARAM lparam)
{
    FIXME("(%ld, %p): stub!\n", dwProcessId, fp);
    return 0;
}

/***********************************************************************
 *      VDMEnumProcessWOW  (VDMDBG.@)
 */
INT WINAPI VDMEnumProcessWOW(PROCESSENUMPROC fp, LPARAM lparam)
{
    FIXME("%p: stub!\n", fp);
    return 0;
}
